# - Config file for the IGNITION-TRANSPORT package.
#
# For finding and loading IGNITION-TRANSPORT from your project, type:
#
# find_package(ignition-transport3)
#
# It defines the following variables:
#
#  ignition-transport3_FOUND       - System has IGNITION-TRANSPORT.
#  IGNITION-TRANSPORT_INCLUDE_DIRS - include directories for IGNITION-TRANSPORT and its dependencies.
#  IGNITION-TRANSPORT_LIBRARY_DIRS - Paths in which the linker should search for libraries.
#  IGNITION-TRANSPORT_LIBRARIES    - Libraries to link against.
#  IGNITION-TRANSPORT_CXX_FLAGS    - Compiler flags for compiling C++ sources.
#  IGNITION-TRANSPORT_LDFLAGS      - Linker flags.

include (FindPkgConfig REQUIRED)

if (IGNITION-TRANSPORT_CONFIG_INCLUDED)
  return()
endif()
set(IGNITION-TRANSPORT_CONFIG_INCLUDED TRUE)

list(APPEND IGNITION-TRANSPORT_INCLUDE_DIRS
"/usr/include/ignition/transport3")

list(APPEND IGNITION-TRANSPORT_LIBRARY_DIRS
"/usr/lib/x86_64-linux-gnu")

# Visual Studio enables c++11 support by default
if (NOT MSVC)
  list(APPEND IGNITION-TRANSPORT_CXX_FLAGS -std=c++11)
endif()
if (${CMAKE_CXX_COMPILER_ID} MATCHES "Clang")
  set(IGNITION-TRANSPORT_CXX_FLAGS "${IGNITION-TRANSPORT_CXX_FLAGS} -stdlib=libc++")
endif ()

# On Windows we need to link against .lib files with no prefix.
if (WIN32)
  SET(CMAKE_FIND_LIBRARY_PREFIXES "")
  SET(CMAKE_FIND_LIBRARY_SUFFIXES ".lib")
endif()

foreach(lib ignition-transport3)
  set(onelib "${lib}-NOTFOUND")
  find_library(onelib ${lib}
    PATHS "/usr/lib/x86_64-linux-gnu"
    NO_DEFAULT_PATH
    )
  if(NOT onelib)
    message(FATAL_ERROR "Library '${lib}' in package IGNITION-TRANSPORT is not installed properly")
  endif()
  list(APPEND IGNITION-TRANSPORT_LIBRARIES ${onelib})
endforeach()

# Protobuf dependency.
if (NOT Protobuf_FOUND)
  find_package(Protobuf REQUIRED)
endif()
list(APPEND IGNITION-TRANSPORT_INCLUDE_DIRS ${PROTOBUF_INCLUDE_DIR})
list(APPEND IGNITION-TRANSPORT_LIBRARIES ${PROTOBUF_LIBRARIES})
list(APPEND IGNITION-TRANSPORT_LIBRARY_DIRS ${PROTOBUF_LIBRARY_DIR})

# ZeroMQ dependency.
if (NOT ZeroMQ_FOUND)
  if (NOT ZeroMQ_ROOT_DIR)
    set(ZeroMQ_ROOT_DIR "")
  endif()
  include ("/usr/lib/x86_64-linux-gnu/cmake/ignition-transport3/FindZeroMQ.cmake")
endif()
list(APPEND IGNITION-TRANSPORT_INCLUDE_DIRS ${ZeroMQ_INCLUDE_DIRS})
list(APPEND IGNITION-TRANSPORT_LIBRARY_DIRS ${ZeroMQ_LIBRARY_DIRS})
list(APPEND IGNITION-TRANSPORT_LIBRARIES ${ZeroMQ_LIBRARIES})

# cppzmq dependency.
if (NOT cppzmq_FOUND)
  find_path(cppzmq_INCLUDE_DIRS
            zmq.hpp
            PATHS
              ${ZeroMQ_INCLUDE_DIR}
              ${ZeroMQ_INCLUDEDIR}
              ${CPPZMQ_HEADER_PATH}
              "")
endif()
list(APPEND IGNITION-TRANSPORT_INCLUDE_DIRS ${cppzmq_INCLUDE_DIRS})

# uuid dependency.
if (UNIX)
  if (NOT uuid_FOUND)
    pkg_check_modules(uuid uuid)
  endif()
  list(APPEND IGNITION-TRANSPORT_INCLUDE_DIRS ${uuid_INCLUDE_DIRS})
  list(APPEND IGNITION-TRANSPORT_LIBRARIES ${uuid_LIBRARIES})
  list(APPEND IGNITION-TRANSPORT_LIBRARY_DIRS ${uuid_LIBDIR})
endif()

if (MSVC)
  list(APPEND IGNITION-TRANSPORT_LIBRARIES Ws2_32.lib Iphlpapi.lib)
endif()

list(APPEND IGNITION-TRANSPORT_LDFLAGS -L"/usr/lib/x86_64-linux-gnu")

#################################################
# Find ign msgs library
find_package(ignition-msgs0 QUIET)
if (NOT ignition-msgs0_FOUND)
  message(FATAL "Looking for ignition-msgs - not found")
else()
  message(STATUS "Looking for ignition-msgs - found")
endif()
list(APPEND IGNITION-TRANSPORT_INCLUDE_DIRS ${IGNITION-MSGS_INCLUDE_DIRS})
list(APPEND IGNITION-TRANSPORT_LIBRARY_DIRS ${IGNITION-MSGS_LIBRARY_DIRS})
list(APPEND IGNITION-TRANSPORT_LIBRARIES ${IGNITION-MSGS_LIBRARIES})
